clear all

version 7.0

use C:\Mislav\45_Stata_outputs\2011\Profiler_CO2\ProfCO2_raw_final

* Data loading and discarding of duplicates
*______________________________________________________________________________________________________________________________
sort level year doy hhmm 
gen duplicate=1 if year==year[_n-1] & doy==doy[_n-1] & hhmm==hhmm[_n-1] & level==level[_n-1]
drop if duplicate==1
drop duplicate
drop meas lev_temp
replace hhmm=2400 if hhmm==0
*______________________________________________________________________________________________________________________________

ren  lev_CO2 CO2prof
ren lev_Ea Rhprof
ren Prof_T T_air_prof
ren lev_h height
ren lev_Press Pressure
sort year doy hhmm

* Absolute limits check
*______________________________________________________________________________________________________________________________
replace CO2prof=. if CO2prof<300
replace CO2prof=. if CO2prof>900
save C:\Mislav\45_Stata_outputs\2011\Profiler_CO2\ProfCO2_raw_final_2011, replace
*______________________________________________________________________________________________________________________________

* Merging with meteo data
*______________________________________________________________________________________________________________________________
use C:\Mislav\45_Stata_outputs\2011\Meteo_data_2011
*drop if doy<128 & year==2008
sort year doy hhmm
merge year doy hhmm using C:\Mislav\45_Stata_outputs\2011\Profiler_CO2\ProfCO2_raw_final_2011
keep timestamp year doy hhmm Ta Rh Pa statatime level height  CO2prof Rhprof Pressure T_air_prof
*______________________________________________________________________________________________________________________________

* Pressure of SBA  (in mb) -> conversion into kPa requres /10; before tower upgrade we had Pa from Li-Cor
*______________________________________________________________________________________________________________________________
replace Pa=101.3 if Pa==.
gen rho=44.6
replace rho=44.6*(Pa/101.3)*273.15/(273.15+T_air_prof) if T_air_prof!=.
replace rho=44.6*(Pa/101.3)*273.15/(273.15+Ta) if T_air_prof==. & Ta!=.
replace CO2prof=CO2prof*rho/1000000
*______________________________________________________________________________________________________________________________

drop rho
drop Ta Rh Pa
drop T_air_prof Pressure Rh 
ren CO2prof CO2_molm3_
drop if level==.

* Calculation of CO2 storage
*______________________________________________________________________________________________________________________________
reshape wide  height CO2_molm3_, i(year doy hhmm) j(level)
sort year doy hhmm
gen CO2storage=.
replace CO2storage=1/2*(CO2_molm3_1*(1+2)+CO2_molm3_2*(1+2)+CO2_molm3_3*(2+4)+CO2_molm3_4*(4+8)+CO2_molm3_5*(8+7)+CO2_molm3_6*7) if (year<=2011 & doy<=90 & CO2_molm3_1!=. & CO2_molm3_2!=. & CO2_molm3_3!=. & CO2_molm3_4!=. & CO2_molm3_5!=. & CO2_molm3_6!=.)
replace CO2storage=1/2*(CO2_molm3_1*(1+2)+CO2_molm3_2*(1+2)+CO2_molm3_3*(2+4)+CO2_molm3_4*(4+8)+CO2_molm3_5*(8+11)+CO2_molm3_6*11) if (year>=2011 & doy>90 & CO2_molm3_1!=. & CO2_molm3_2!=. & CO2_molm3_3!=. & CO2_molm3_4!=. & CO2_molm3_5!=. & CO2_molm3_6!=.)
gen storage_flux=.
replace storage_flux=(CO2storage-CO2storage[_n-1])/1800*1000000 if (CO2storage[_n-1]!=. & CO2storage!=.)
order year doy hhmm
drop height1 - CO2storage
sort year doy hhmm 
save C:\Mislav\45_Stata_outputs\2011\Profiler_CO2\Service_profiler_2011, replace
*______________________________________________________________________________________________________________________________

* Merging with empty timestamp
*______________________________________________________________________________________________________________________________
use C:\Mislav\empty_met_timestamp\2011.dta
sort year doy hhmm
merge year doy hhmm using C:\Mislav\45_Stata_outputs\2011\Profiler_CO2\Service_profiler_2011
drop _m timestamp time
*______________________________________________________________________________________________________________________________

sort year doy hhmm
save C:\Mislav\45_Stata_outputs\2011\Profiler_CO2\Service_profiler_2011, replace
