clear all

version 7.0

*__________________________________________________________________________________________________________________

* Preparing data for gap-filling

*__________________________________________________________________________________________________________________


* Loading data and converting dataset to format for gap-filling
*__________________________________________________________________________________________________________________
use C:\Mislav\45_Stata_outputs\2015\eddy_hr_2015_v6

drop ta_measured percent_measured_ta Tc ts5cm_measured percent_measured_ts5cm rg_measured percent_measured_rg rh_measured percent_measured_rh SWC1 Tau qcTau

ren doy Day
ren hhmm Hour
ren qcFc qcNEE
ren Fc NEE
ren Ta Tair
ren Ts1 Tsoil
ren Rh rH
ren P precip
ren ustar Ustar
ren year Year
ren month Month

gen service=Hour/100-int(Hour/100)
gen mm=0.5 if service>0
replace mm=0 if mm==.
drop service
gen Hour01=int(Hour/100)+mm
drop timestamp
drop Hour mm  
ren Hour01 Hour
order Year Month Day hour minute Hour time qcNEE NEE Sc LE H Rg Tair Tsoil rH precip Ustar 
sort Year Day Hour

replace qcNEE=-9999 if NEE==-9999
replace NEE=. if qcNEE==2
replace NEE=NEE+Sc if Sc!=. & NEE!=.
replace NEE=. if NEE<-50 | NEE>30
replace qcNEE=-9999 if qcNEE==.
replace LE=-9999 if LE==.
replace H=-9999 if H==.
replace Tair=-9999 if Tair==.
replace Tsoil=-9999 if Tsoil==.
replace rH=-9999 if rH==.
replace precip=-9999 if precip==.
replace Ustar=-9999 if Ustar==.
replace Rg=-9999 if Rg==.
format NEE %8.2f
format LE %8.2f
format H %8.2f

order Year Day Hour
replace Day=Day+1 if Hour==24
replace Hour=0 if Hour==24
gen service=1 if Day==366 & Year==2015 & Hour==0
replace Day=1 if service==1
replace Year=Year+1 if service==1
drop service 
drop if Year==Year[_n-1] & Day==Day[_n-1] & Hour==Hour[_n-1]
replace LE=-9999 if qcLE==2
replace H=-9999 if qcH==2
drop Sc hour minute time date day qcLE qcH
sort Year Day Hour 
 
save C:\Mislav\45_Stata_outputs\2015\eddy_hr_2015_for_gf_v6, replace
*__________________________________________________________________________________________________________________

* NEE filtering, according to Papale, 2006
*__________________________________________________________________________________________________________________
gen NEE_cor=NEE
gen median_night=1.150293 
gen d_night=.
gen z_night=4
replace d_night=(NEE[_n]-NEE[_n-1])-(NEE[_n+1]-NEE[_n]) if Rg[_n]<20 
gen mad_night=4.448052
replace NEE_cor=. if d_night<median_night-z_night*mad_night/0.6745 | d_night>median_night+z_night*mad_night/0.6745 & Rg<20

gen median_day=-4.421843
gen z_day=5.5
gen d_day=.
replace d_day=(NEE[_n]-NEE[_n-1])-(NEE[_n+1]-NEE[_n]) if Rg[_n]>20 
gen mad_day=5.883593 
replace NEE_cor=. if d_day<median_day-z_day*mad_day/0.6745 | d_day>median_day+z_day*mad_day/0.6745 & Rg>20
*__________________________________________________________________________________________________________________

replace NEE_cor=-9999 if NEE_cor==.
replace NEE=-9999 if NEE==.

* Discarding of bad data during winter
*__________________________________________________________________________________________________________________
replace NEE_cor=-9999 if rH>99 & Day<90
replace NEE_cor=-9999 if rH>99 & Day>330
replace NEE_cor=-9999 if Rg<20 & NEE_cor<0 & Day<70
replace NEE_cor=-9999 if Rg<20 & NEE_cor<0 & Day>320
replace NEE_cor=-9999 if Day==1 & Hour>11.5 & Hour<15.5
*__________________________________________________________________________________________________________________ 

drop NEE median_night-mad_day Month
ren NEE_cor NEE
ren Day DoY
format NEE %8.2f
replace NEE=-9999 if NEE==-9999.00

order Year DoY  Hour qcNEE NEE LE H Rg Tair Tsoil rH precip Ustar
save C:\Mislav\55_Gapfilling\eddy_hr_2015_before_jena_v6, replace
outsheet Year DoY Hour NEE LE H Rg Tair Tsoil rH Ustar using C:\Mislav\55_Gapfilling\cro_2015_v6.txt, replace
*__________________________________________________________________________________________________________________
