clear all

version 7.0

* Loading calculated fluxes from EdiRe
*____________________________________________________________________________________________________________
insheet using C:\Mislav\04_edire_output\2012\flux_calculation_2012.csv

keep datetime wddegn umeanms1 vmeanms1 wmeanms1 tvmeanc cmeanmmolm3 qmeanmmolm3 tmeanc cmeanumolmol wsms1 ustarms1 zol  ekpa le_frequency_corrected fc_frequency_corrected tau_freq_corrected h_freq_corrected lecorrected fcorrected stat_wc stat_wq stat_wt stat_tau

ren wddegn wd
format wd %8.0f
ren umeanms1 Umean
ren vmeanms1 Vmean
ren wmeanms1 Wmean
ren tvmeanc Tvmean
ren tmeanc Tmean
ren cmeanmmolm3 CO2mmol
ren qmeanmmolm3 H2O
ren wsms1 ws
format ws %8.2f
ren cmeanumolmol CO2
format CO2 %8.2f
ren ustarms1 u_star
format u_star %8.2f
ren zol ZL
format ZL %8.2f
ren lecorrected LE_corrected
ren fcorrected Fc_corrected
ren stat_wc qcFc
ren stat_wq qcLE
ren stat_wt qcH
ren stat_tau qcTau
ren h_freq_corrected H_corrected
ren  tau_freq_corrected Tau_corrected
ren ekpa e_kpa
format e_kpa %8.2f

* Converting of H2O concentration: mmol/m^3 -> mmol/mol
*_ _ _ _ _ _ _  _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
* Vm = [m^3 mol-1], Vm depends on T as Vm(t[C]) = (0.0821*t+22.414) [dm3 mol-1]
* we don't have P_air measuremets => P_air = P_0 = 101300 Pa
* density = molar density of (ideal) gas at P and T 
* density =(n0/Vm)*(P_air/P_0) * T0/T = in our case = (1/Vm) * T0/T [mol/m^3]
gen density=1000/(0.0821*Tmean+22.414)*273.15/(Tmean+273.15)
replace H2O=H2O/density
*_ _ _ _ _ _ _  _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _

gen str10 date=substr( datetime,1,index( datetime," "))
generate bdate = date( date, "dm20y")
format bdate %d
gen year=year(bdate)
generate doy = bdate-date( "2012/01/01", "ymd")+1 if year==2012
gen str10 hour=substr( datetime,index( datetime," ")+1,5)
gen str10 hh=substr(hour,1,2)
gen str10 mm=substr(hour,4,2)
gen hhmm=real(hh)*100+real(mm)
replace hour=substr( datetime,index( datetime," ")+1,4) if hhmm==.
replace hh=substr(hour,1,1) if hhmm==.
replace mm=substr(hour,3,2) if hhmm==.
replace hhmm=real(hh)*100+real(mm) if hhmm==.
replace doy=doy-1 if hhmm==0
replace hhmm=2400 if hhmm==0
gen min=hhmm-int(hhmm/100)*100
replace hhmm=hhmm+15 if min==15
replace hhmm=hhmm+55 if min==45
drop min
drop hour bdate date datetime hh mm
order year doy hhmm

ren Fc_corrected Fc
ren H_corrected H
ren Tmean Tair
ren LE_corrected LE
ren Tau_corrected Tau
format H2O %8.2f
format Tair %8.2f
order  year doy hhmm wd ws Tair CO2 H2O Fc qcFc H qcH LE qcLE Tau qcTau u_star
sort year doy hhmm
ren Tvmean Tsonic
drop  Umean-Wmean
save C:\Mislav\04_edire_output\edire_output_2012_v6, replace
*____________________________________________________________________________________________________________

* Merging with empty timestamp
*____________________________________________________________________________________________________________
use C:\Mislav\empty_met_timestamp\2012.dta
sort year doy hhmm
merge year doy hhmm using C:\Mislav\04_edire_output\edire_output_2012_v6
drop _m
sort year doy hhmm
replace day=day-1 if hhmm==2400
replace day=31 if timestamp=="2012-02-01 00:00"
replace day=29 if timestamp=="2012-03-01 00:00"
replace day=31 if timestamp=="2012-04-01 00:00"
replace day=30 if timestamp=="2012-05-01 00:00"
replace day=31 if timestamp=="2012-06-01 00:00"
replace day=30 if timestamp=="2012-07-01 00:00"
replace day=31 if timestamp=="2012-08-01 00:00"
replace day=31 if timestamp=="2012-09-01 00:00"
replace day=30 if timestamp=="2012-10-01 00:00"
replace day=31 if timestamp=="2012-11-01 00:00"
replace day=30 if timestamp=="2012-12-01 00:00"
replace day=31 if timestamp=="2013-01-01 00:00"
save C:\Mislav\45_Stata_outputs\2012\eddy_hr_2012_v6, replace
*____________________________________________________________________________________________________________

* Merging with meteo data
*____________________________________________________________________________________________________________
use C:\Mislav\45_Stata_outputs\2012\Meteo_data_2012.dta
sort year doy hhmm
merge year doy hhmm using C:\Mislav\45_Stata_outputs\2012\eddy_hr_2012_v6
drop _m
drop  Ts2- SWC3
format agc_avg %8.2f
order timestamp year month doy  hour minute hhmm time
save C:\Mislav\45_Stata_outputs\2012\eddy_hr_2012_v6, replace
*____________________________________________________________________________________________________________

* Data quality check
*____________________________________________________________________________________________________________
replace WS=ws if WS==.
replace WD=wd if WD==.
replace Rn=Rn*(1+0.001*ws^(3/4)) if ws!=.
gen diff=Rg-Rn
replace Rn=. if Rn>500 & Rg<1000 & diff<200
replace Rn=0.60*Rg-32 if Rg!=. & Rn==.
drop diff
replace Rn=. if Rn>800 | Rn<-500

replace Tau=Tau/(-1000)
replace Rh=. if Rh>100 | Rh<0
replace CO2=. if CO2<300 | CO2>600
replace H2O=. if H2O<0.001 | H2O>40
replace ZL=. if ZL<-50 | ZL>50
replace LE=. if LE<-150 | LE>800
replace Tau=. if Tau<0 | Tau>5
replace u_star=. if u_star<0 | u_star>3.5
replace Fc=. if Fc<-50 | Fc>30
replace H=. if H<-150 | H>500
replace fc_frequency_corrected=. if fc_frequency_corrected<-50 | fc_frequency_corrected>30
replace le_frequency_corrected=. if le_frequency_corrected<-150 | le_frequency_corrected>800

replace qcFc=0 if qcFc<51
replace qcFc=1 if qcFc>50 & qcFc<501
replace qcFc=2 if qcFc>501
replace qcFc=. if Fc==.

replace qcLE=0 if qcLE<51
replace qcLE=1 if qcLE>50 & qcLE<501 
replace qcLE=2 if qcLE>501 
replace qcLE=. if LE==.

replace qcH=0 if qcH<51
replace qcH=1 if qcH>50 & qcH<501
replace qcH=2 if qcH>501
replace qcH=. if H==.

replace qcTau=0 if qcTau<51
replace qcTau=1 if qcTau>50 & qcTau<501
replace qcTau=2 if qcTau>501
replace qcTau=. if Tau==.

gen filter=0
replace filter=1 if agc_avg>60 & agc_avg!=.
replace filter=1 if Fc<-10 & doy<60 & year==2008

replace CO2=. if filter==1
replace H2O=. if filter==1
replace u_star=. if filter==1
replace ZL=. if filter==1
replace Fc=. if filter==1
replace LE=. if filter==1
replace H=. if filter==1
replace Tau=. if filter==1
replace fc_frequency_corrected=. if filter==1

drop filter

replace qcFc=. if Fc==.
replace qcLE=. if LE==.
replace qcH=. if H==.
replace qcTau=. if Tau==.

drop Tair
ren wd wd_sonic
ren ws ws_sonic
*ren WD wd
*ren WS ws
ren u_star ustar

* H2O check: LI-COR sensor overestimates measurements of H2O, thus it will be corrected with Vaisala measurements
*_ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ 
 * Tetens formula for saturation vapor pressure
gen es_meteo=0.611*exp(17.502* Ta/( Ta+240.97)) if Rh!=.
*  Calculation of real vapor pressure
gen ea_meteo=es_meteo* Rh/100                            
replace ea_meteo=ea_meteo/101.3*1000
gen H2O_corr=.
*gen RH_licor=H2O*101.3/1000/es_meteo*100
regress ea_meteo H2O 
gen coef_a=_b[H2O]
gen ste_a=_se[H2O]
gen coef_b=_b[_cons]
gen ste_b=_se[_cons]
gen S=ste_b*sqrt(11482)
gen b_d=coef_b-S
gen b_g=coef_b+S
gen y_g=coef_a*H2O+b_g
gen y_d=coef_a*H2O+b_d
gen flag_1=0
replace flag_1=1 if H2O>y_g | H2O<y_d
replace H2O_corr=H2O if flag_1==0

regress ea_meteo H2O_corr 
replace coef_a=_b[H2O_corr]
replace ste_a=_se[H2O_corr]
replace coef_b=_b[_cons]
replace ste_b=_se[_cons]
replace H2O_cor=coef_a*H2O_corr+coef_b if H2O_corr!=.
drop flag_1
gen LE_calibrat=coef_a*LE
replace le_frequency_corrected=LE_calibrat
*_ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ 

gen filter=1 if H2O==. & CO2==.
replace ustar=. if filter==1
replace ZL=. if filter==1
replace Fc=. if filter==1
replace LE=. if filter==1
replace LE_calibrat=. if filter==1
replace H=. if filter==1
replace Tau=. if filter==1
drop filter Fc LE

* WPL correction
*_ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ 
* Dry air density [kg air m-3]
gen rho_dry=101.3*1000/(287.05*(273.15+Tsonic))
* Mean water vapor density [kg H2O m-3], density [mol m-3]
gen rho_vp=H2O*density
replace rho_vp=rho_vp/1000*18/1000
* Ratio between rho_vp and rho_dry
gen ratio =rho_vp/rho_dry
* Mean ambient density of CO2 [kg m-3]
gen qCO2=CO2mmol
gen rho_c=qCO2*44/1000000
* Total air density [kg/ m-3]
gen tot_air_density=101325/(287*(273.15+Ta))

gen LE_WPL_corrected=(1+1.6077*ratio)*(le_frequency_corrected/(2260*1000)+H/(tot_air_density*1006)*rho_vp/(273.15+Ta))
gen Fc_WPL_correction=1.6077*LE_WPL_corrected*rho_c/(rho_dry*(1+1.6077*ratio))+H*rho_c/(tot_air_density*1006*(273.15+Ta))
* Coversion of LE to W/m2
replace LE_WPL_corrected=LE_WPL_corrected*2260*1000
* Conversion of Fc to umol m-2 s-1
replace Fc_WPL_correction=Fc_WPL_correction*1000/44*1000000
gen Fc_WPL_corrected=fc_frequency_corrected+Fc_WPL_correction
drop e_kpa le_frequency_corrected fc_frequency_corrected ea_meteo LE_calibrat rho_dry rho_vp ratio rho_c Fc_WPL_correction

ren Fc_WPL_corrected Fc
ren LE_WPL_corrected LE
sort year doy hhmm
*____________________________________________________________________________________________________________


* Merging with profiler measurement
*____________________________________________________________________________________________________________
save C:\Mislav\45_Stata_outputs\2012\eddy_hr_2012_v6, replace
sort year doy hhmm
merge year doy hhmm using C:\Mislav\45_Stata_outputs\2012\Profiler_CO2\Service_profiler_2012
drop _m
gen Sc=storage_flux if storage_flux!=.
drop storage_flux 
replace Pa=101.3 if Pa==.
gen Licor_sc=(CO2[_n]-CO2[_n-1])*44.6*(Pa/101.3)*273.15/(273.15+Ta)*27/1800 if Ta!=.
replace Licor_sc=. if Licor_sc<-50 | Licor_sc>30
*____________________________________________________________________________________________________________

* Sc correction
*____________________________________________________________________________________________________________
replace Sc=Licor_sc if Sc==.
replace Sc=Licor_sc if doy==3 & hhmm>400 & hhmm<1700
replace Sc=Licor_sc if doy==12 & hhmm>630 & hhmm<1030
replace Sc=Licor_sc if doy==13 & hhmm>700 & hhmm<1000
replace Sc=Licor_sc if doy==14 & hhmm>430 & hhmm<1100
replace Sc=Licor_sc if doy==15 & hhmm>200 & hhmm<1200
replace Sc=Licor_sc if doy==16 
replace Sc=Licor_sc if doy==19
replace Sc=Licor_sc if doy==23 & hhmm>500 & hhmm<1200
replace Sc=Licor_sc if doy==26 & hhmm>300 & hhmm<1300
replace Sc=Licor_sc if doy==29
replace Sc=Licor_sc if doy==30
replace Sc=Licor_sc if doy==31
replace Sc=Licor_sc if doy==32
replace Sc=Licor_sc if doy==33
replace Sc=Licor_sc if doy==39
replace Sc=Licor_sc if doy==40
replace Sc=Licor_sc if doy==47
replace Sc=Licor_sc if doy==53
replace Sc=Licor_sc if doy==54
replace Sc=Licor_sc if doy==55
replace Sc=Licor_sc if doy==56
replace Sc=Licor_sc if doy==57
replace Sc=Licor_sc if doy==58
replace Sc=Licor_sc if doy==128 & hhmm>1700
replace Sc=Licor_sc if doy>=129 & doy<=133
replace Sc=Licor_sc if doy==135
replace Sc=Licor_sc if doy==136
replace Sc=Licor_sc if doy>=138 & doy<=151
replace Sc=Licor_sc if doy==224 & hhmm>30 & hhmm<1300
replace Sc=Licor_sc if doy==225 & hhmm>30 & hhmm<1300
replace Sc=Licor_sc if doy==226 & hhmm>30 & hhmm<1300
replace Sc=Licor_sc if doy==227 & hhmm>30 & hhmm<1300
replace Sc=Licor_sc if doy==228 & hhmm<1100
replace Sc=Licor_sc if doy==229 & hhmm<1100
replace Sc=Licor_sc if doy==230 & hhmm<1130
replace Sc=Licor_sc if doy==234 & hhmm>730 & hhmm<1230
replace Sc=Licor_sc if doy==240 & hhmm<1100
replace Sc=Licor_sc if doy==241 & hhmm<1100
replace Sc=Licor_sc if doy==242 & hhmm<1300
replace Sc=Licor_sc if doy==243 & hhmm<1300
replace Sc=Licor_sc if doy==317
replace Sc=Licor_sc if doy==331 & hhmm<1400
drop Licor_sc
*____________________________________________________________________________________________________________ 


* Merging with gap-filled Rg time series
*____________________________________________________________________________________________________________
save C:\Mislav\45_Stata_outputs\2012\eddy_hr_2012_v6, replace
sort year doy hour minute
merge year doy hour minute using C:\Mislav\55_Gapfilling\Outputs\Rg_2012_gf
drop _m
format Rg_f %8.0f
replace Rg=Rg_f if Rg==.
drop Rg_f
sort time
*____________________________________________________________________________________________________________

order timestamp 
drop Tsonic- tot_air_density
save C:\Mislav\45_Stata_outputs\2012\eddy_hr_2012_v4, replace

replace month=12 if time==367
replace hour=0 if time==367
replace minute=0 if time==367
drop if month==.

* Searching and discarding of duplicates
*____________________________________________________________________________________________________________
gen duplicate=1 if year==year[_n-1] & doy==doy[_n-1] & hhmm==hhmm[_n-1]
drop if duplicate==1
drop duplicate 
*____________________________________________________________________________________________________________

order  timestamp date year month day doy hour minute hhmm time  Fc qcFc LE qcLE H qcH Tau qcTau Sc ustar Ta ta_measured percent_measured_ta Tc Ts1 ts5cm_measured percent_measured_ts5cm Rg rg_measured percent_measured_rg Rh rh_measured percent_measured_rh P SWC1
drop  agc_avg- H2O

save C:\Mislav\45_Stata_outputs\2012\eddy_hr_2012_v6, replace
*____________________________________________________________________________________________________________



